[or-cvs] r23801: {arm} Changing installation location from /usr/lib to /usr/share ( (in arm/trunk: . src)

Damian Johnson atagar1 at gmail.com
Mon Nov 15 04:34:55 UTC 2010


Author: atagar
Date: 2010-11-15 04:34:55 +0000 (Mon, 15 Nov 2010)
New Revision: 23801

Modified:
   arm/trunk/arm
   arm/trunk/install
   arm/trunk/setup.py
   arm/trunk/src/uninstall
Log:
Changing installation location from /usr/lib to /usr/share (request by weasel)



Modified: arm/trunk/arm
===================================================================
--- arm/trunk/arm	2010-11-15 04:25:37 UTC (rev 23800)
+++ arm/trunk/arm	2010-11-15 04:34:55 UTC (rev 23801)
@@ -1,6 +1,6 @@
 #!/bin/sh
 if [ $0 = /usr/bin/arm ]; then
-  arm_base=/usr/lib/arm/
+  arm_base=/usr/share/arm/
 else
   arm_base=$( dirname $0 )/src/
 fi

Modified: arm/trunk/install
===================================================================
--- arm/trunk/install	2010-11-15 04:25:37 UTC (rev 23800)
+++ arm/trunk/install	2010-11-15 04:34:55 UTC (rev 23801)
@@ -6,7 +6,7 @@
   
   # provide notice if we installed successfully
   if [ $? = 0 ]; then
-    echo "installed to /usr/lib/arm"
+    echo "installed to /usr/share/arm"
   fi
   
   # cleans up the automatically built temporary files

Modified: arm/trunk/setup.py
===================================================================
--- arm/trunk/src/uninstall	2010-11-15 04:25:37 UTC (rev 23800)
+++ arm/trunk/src/uninstall	2010-11-15 04:34:55 UTC (rev 23801)
@@ -1,5 +1,5 @@
 #!/bin/sh
-files="/usr/bin/arm /usr/share/man/man1/arm.1.gz /usr/lib/arm"
+files="/usr/bin/arm /usr/share/man/man1/arm.1.gz /usr/share/arm"
 
 for i in $files 
 do



More information about the tor-commits mailing list
--- arm/trunk/setup.py	2010-11-15 04:25:37 UTC (rev 23800)
+++ arm/trunk/setup.py	2010-11-15 04:34:55 UTC (rev 23801)
@@ -5,15 +5,15 @@
 from src.version import VERSION
 from distutils.core import setup
 
 # Provides the configuration option to install to "/usr/lib" rather than as a
 # python module. Alternatives are to either provide this as an input argument
 # (not an option for deb/rpm builds) or add a setup.cfg with:
 #   [install]
-#   install-purelib=/usr/lib
+#   install-purelib=/usr/share
 # which would mean a bit more unnecessary clutter.
 
 if "install" in sys.argv:
-  sys.argv += ["--install-purelib", "/usr/lib"]
+  sys.argv += ["--install-purelib", "/usr/share"]
 
 # Compresses the man page. This is a temporary file that we'll install. If
 # something goes wrong then we'll print the issue and use the uncompressed man
@@ -44,7 +44,7 @@
       package_dir={'arm': 'src'},
       data_files=[("/usr/bin", ["arm"]),
                   ("/usr/share/man/man1", [manFilename]),
-                  ("/usr/lib/arm", ["src/settings.cfg"])],
+                  ("/usr/share/arm", ["src/settings.cfg"])],
      )
 
 # Cleans up the temporary compressed man page.
@@ -56,7 +56,7 @@
 # (hardcoded in distutils/command/install.py), nor are there any arguments to
 # bypass its creation.
 # TODO: not sure how to remove this from the deb build too...
-eggPath = '/usr/lib/arm-%s.egg-info' % VERSION
+eggPath = '/usr/share/arm-%s.egg-info' % VERSION
 if os.path.isfile(eggPath):
   if "-q" not in sys.argv: print "Removing %s" % eggPath
   os.remove(eggPath)
@@ -5,15 +5,15 @@
 from distutils.core import setup
 
-# Provides the configuration option to install to "/usr/lib" rather than as a
+# Provides the configuration option to install to "/usr/share" rather than as a
 # python module. Alternatives are to either provide this as an input argument
 # (not an option for deb/rpm builds) or add a setup.cfg with:

Modified: arm/trunk/src/uninstall
===================================================================